#!/usr/bin/env python
# -*- coding: utf-8 -*-
# -*- Python -*-

"""
 @file MapDataDBControl.py
 @brief 本モジュールは、地図データのＤＢへの登録・削除や、データの読み出しなどを行う
 @date $Date$

 @author 株式会社 東日本計算センター

 プロジェクト方針決定後に記載

"""

# ===== インポートモジュール======
import csv					# //標準
import datetime				# //標準
import json					# //標準
import MySQLdb				# //MySQL
import os					# //標準
import io					# //標準
import shutil				# //標準：フォルダ削除
# ========== ユーザー共通 ==========
import VersatileOverheadSystem as imp_Versatile

import sys
import time
sys.path.append(".")

# Import RTM module
import RTC
import OpenRTM_aist

import MapDataDBControl_idl

# Import Service implementation class
# <rtc-template block="service_impl">
from MapDataDBControl_idl_example import *

# </rtc-template>

# Import Service stub modules
# <rtc-template block="consumer_import">
# </rtc-template>


# This module's spesification
# <rtc-template block="module_spec">
mapdatadbcontrol_spec = ["implementation_id", "MapDataDBControl",
                         "type_name",         "MapDataDBControl",
                         "description",       "本モジュールは、地図データのＤＢへの登録・削除や、データの読み出しなどを行う",
                         "version",           "1.0.0",
                         "vendor",            "EAC",
                         "category",          "Category",
                         "activity_type",     "STATIC",
                         "max_instance",      "1",
                         "language",          "Python",
                         "lang_type",         "SCRIPT",
                         "conf.default.confAlignmentSeq", "ASC ",
                         "conf.__widget__.confAlignmentSeq", "text",
                         "conf.__constraints__.confAlignmentSeq", "(ASC,DESC)",
                         ""]
# </rtc-template>

##
# @class MapDataDBControl
# @brief 本モジュールは、地図データのＤＢへの登録・削除や、データの読み出しなどを行う
#
# 別紙"機能仕様書_地図データDB制御RTC"参照
#
# 別紙"機能仕様書_地図データDB制御RTC"参照
#
# 別紙"機能仕様書_地図データDB制御RTC"参照
#
# 別紙"機能仕様書_地図データDB制御RTC"参照
#
#


class MapDataDBControl(OpenRTM_aist.DataFlowComponentBase):

    ##
    # @brief constructor
    # @param manager Maneger Object
    #
    def __init__(self, manager):
        OpenRTM_aist.DataFlowComponentBase.__init__(self, manager)

        self._d_outSynthesisPlanList = RTC.TimedStringSeq(RTC.Time(0, 0), [])
        """
		地図データDB内の合成計画リストをJson形式で提供する
		 - Type: RTC::TimedStringSeq
		 - Number: MAX１００件
		 - Frequency: 1秒周期
		 - Operation Cycle: 1秒周期
        """
        self._outSynthesisPlanListOut = OpenRTM_aist.OutPort(
            "outSynthesisPlanList", self._d_outSynthesisPlanList)
        self._d_outMapAdditinalInfo = RTC.TimedString(RTC.Time(0, 0), 0)
        """
		地図データDB内から指定された「グループID」の地図画像付加情報をJson形式で提供
		する
		 - Type: RTC::TimedString
		"""
        self._outMapAdditinalInfoOut = OpenRTM_aist.OutPort(
            "outMapAdditinalInfo", self._d_outMapAdditinalInfo)
        self._d_outMapAdditinalData = RTC.TimedString(RTC.Time(0, 0), 0)
        """
		地図データDB内から該当する「タイル座標」の画像付加データをJson形式で提供する
		 - Type: RTC::TimedString
		 - Frequency: 1秒周期
		 - Operation Cycle: 1秒周期
		"""
        self._outMapAdditinalDataOut = OpenRTM_aist.OutPort(
            "outMapAdditinalData", self._d_outMapAdditinalData)

        """
		地図データDB要求制御
		"""
        self._MapDataDBReqServPort = OpenRTM_aist.CorbaPort("MapDataDBReqServ")
        """
		地図データDBステータス通知
		"""
        self._MapDataDBStsServPort = OpenRTM_aist.CorbaPort("MapDataDBStsServ")

        """
		地図データDBにデータ登録要求を行う
		 - Argument:      データ登録情報(json形式で設定)
		 - Return Value:  RESULT_ACK　：０ 実行結果OK
		                  RESULT_NACK ：１実行結果NG
		"""
        self._MapDBReqRegistAddDataProv = MapDBReqRegistAddData_i()
        """
		リストから選択した地図画像の情報(X軸方向のタイル画像の総数、Y軸方向のタイル画
		像の総数、タイル画像始点X座標、タイル画像始点Y座標値)を取得する要求を行う
		 - Argument:      (1) 合成計画のグループID
		                  (2)ズームレベル
		 - Return Value:  RESULT_ACK　：０ 実行結果OK
		                  RESULT_NACK ：１実行結果NG
		"""
        self._MapDBReqGetAddDataInfoProv = MapDBReqGetAddDataInfo_i()
        """
		パラメータで指定した地図画像付加データを取得する要求を行う
		 - Argument:      (1)合成計画のグループID
		                  (2)ズームレベル
		                  (3)タイルX座標
		                  (4)タイルY座標
		 - Return Value:  RESULT_ACK　：０ 実行結果OK
		                  RESULT_NACK ：１実行結果NG
		"""
        self._MapDBReqGetAddDataProv = MapDBReqGetAddData_i()
        """
		合成計画リストの作成要求を行う
		 - Argument:      要求有無　0:要求無　1:要求有
		 - Return Value:  RESULT_ACK　：０ 実行結果OK
		                  RESULT_NACK ：１実行結果NG
		"""
        self._MapDBReqMakeSynthesisPlanListProv = MapDBReqMakeSynthesisPlanList_i()
        """
		合成計画リストの取得要求を行う
		 - Argument:      要求有無　0:要求無　1:要求有
		 - Return Value:  RESULT_ACK　：０ 実行結果OK
		                  RESULT_NACK ：１実行結果NG
		"""
        self._MapDBReqGetSynthesisPlanListProv = MapDBReqGetSynthesisPlanList_i()
        """
		合成計画リストの削除要求を行う
		 - Argument:      (1) 合成計画のグループID
		 - Return Value:  RESULT_ACK　：０ 実行結果OK
		                  RESULT_NACK ：１実行結果NG
		"""
        self._MapDBReqDelSynthesisPlanListProv = MapDBReqDelSynthesisPlanList_i()
        """
		地図データDB制御コンポーネントの動作完了を通知する
		 - Argument:      (1)完了通知
		                  (2)第２パラメータ
		 - Return Value:  RESULT_ACK　：０ 実行結果OK
		                  RESULT_NACK ：１実行結果NG
		"""
        self._MapDataDBNoticeProv = MapDataDBNotice_i()

        # initialize of configuration-data.
        # <rtc-template block="init_conf_param">
        """
		合成計画リストの並び順を設定する。
		 - Name: confAlignmentSeq confAlignmentSeq
		 - DefaultValue: ASC 
		 - Unit: 並び順
		 - Range: （ASCｰDESC）
		"""
        self._confAlignmentSeq = ['ASC ']

        # </rtc-template>

    ##
    # 地図データDB制御RTCの初期化処理
    #
    # The initialize action (on CREATED->ALIVE transition)
    # formaer rtc_init_entry()
    #
    # @return RTC::ReturnCode_t
    #
    #
    def onInitialize(self):
        print "[mapdb_debug]onInitialize"

        # Bind variables and configuration variable
        self.bindParameter("confAlignmentSeq", self._confAlignmentSeq, "ASC ")

        # Set InPort buffers

        # Set OutPort buffers
        self.addOutPort("outSynthesisPlanList", self._outSynthesisPlanListOut)
        self.addOutPort("outMapAdditinalInfo", self._outMapAdditinalInfoOut)
        self.addOutPort("outMapAdditinalData", self._outMapAdditinalDataOut)

        # Set service provider to Ports
        self._MapDataDBReqServPort.registerProvider(
            "MapDBReqRegistAddData", 
            "MapDataDBReqServ::MapDBReqRegistAddData", 
            self._MapDBReqRegistAddDataProv)
        self._MapDataDBReqServPort.registerProvider(
            "MapDBReqGetAddDataInfo", 
            "MapDataDBReqServ::MapDBReqGetAddDataInfo", 
            self._MapDBReqGetAddDataInfoProv)
        self._MapDataDBReqServPort.registerProvider(
            "MapDBReqGetAddData", 
            "MapDataDBReqServ::MapDBReqGetAddData", 
            self._MapDBReqGetAddDataProv)
        self._MapDataDBReqServPort.registerProvider(
            "MapDBReqMakeSynthesisPlanList", 
            "MapDataDBReqServ::MapDBReqMakeSynthesisPlanList", 
            self._MapDBReqMakeSynthesisPlanListProv)
        self._MapDataDBReqServPort.registerProvider(
            "MapDBReqGetSynthesisPlanList", 
            "MapDataDBReqServ::MapDBReqGetSynthesisPlanList", 
            self._MapDBReqGetSynthesisPlanListProv)
        self._MapDataDBReqServPort.registerProvider(
            "MapDBReqDelSynthesisPlanList", 
            "MapDataDBReqServ::MapDBReqDelSynthesisPlanList", 
            self._MapDBReqDelSynthesisPlanListProv)
        self._MapDataDBStsServPort.registerProvider(
            "MapDataDBNotice", 
            "MapDataDBStsServ::MapDataDBNotice", 
            self._MapDataDBNoticeProv)

        # Set service consumers to Ports

        # Set CORBA Service Ports
        self.addPort(self._MapDataDBReqServPort)
        self.addPort(self._MapDataDBStsServPort)

        # ===== 変数初期化 =====
        self.versatiInit()

        return RTC.RTC_OK

        ##
        # 地図データDB制御RTの終了処理
        #
        # The finalize action (on ALIVE->END transition)
        # formaer rtc_exiting_entry()
        #
        # @return RTC::ReturnCode_t

        #
    def onFinalize(self):
        print "[mapdb_debug]onFinalize"

        return RTC.RTC_OK

    	##
    	#
    	# The startup action when ExecutionContext startup
    	# former rtc_starting_entry()
    	#
    	# @param ec_id target ExecutionContext Id
    	#
    	# @return RTC::ReturnCode_t
    	#
    	#
    # def onStartup(self, ec_id):
    #
    #	return RTC.RTC_OK

    	##
    	#
    	# The shutdown action when ExecutionContext stop
    	# former rtc_stopping_entry()
    	#
    	# @param ec_id target ExecutionContext Id
    	#
    	# @return RTC::ReturnCode_t
    	#
    	#
    # def onShutdown(self, ec_id):
    #
    #	return RTC.RTC_OK

        ##
        # 地図データDB制御RTCの開始処理
        #
        # The activated action (Active state entry action)
        # former rtc_active_entry()
        #
        # @param ec_id target ExecutionContext Id
        #
        # @return RTC::ReturnCode_t
        #
        #
    def onActivated(self, ec_id):
        print "[mapdb_debug]onActivated"

        # ===== DB接続チェック =====
        ret = self.dbConnectCheck()

        if ret:
            print "[mapdb_debug]", u"dbConnectCheck OK"
        else:
            # //接続NG
            print "[mapdb_error]", u"DB接続できません"
            return RTC.RTC_ERROR

        return RTC.RTC_OK

        ##
        # 地図データDB制御RTの停止処理
        #
        # The deactivated action (Active state exit action)
        # former rtc_active_exit()
        #
        # @param ec_id target ExecutionContext Id
        #
        # @return RTC::ReturnCode_t
        #
        #
    def onDeactivated(self, ec_id):
        print "[mapdb_debug]onDeactivated"

        # ==== DB接続クローズ =====
        if self._dbconnect != None:
            self._dbconnect.close()
        else:
            print u"[mapdb_error]DB接続できません"
            return RTC.RTC_ERROR

        # ===== 変数初期化 =====
        self.versatiInit()

        return RTC.RTC_OK

        ##
        # 地図データDB制御RTCを行う周期処理
        #
        # The execution action that is invoked periodically
        # former rtc_active_do()
        #
        # @param ec_id target ExecutionContext Id
        #
        # @return RTC::ReturnCode_t
        #
        #
    def onExecute(self, ec_id):
        # ===== 処理状態 =====
        if (self._proc_sts == self.PROC_STS_IDLE):

            # ========== 要求チェック ==========
            if self.requestCheck():
                # ===== 処理実行 =====
                if self.procExc():
                    pass
                else:
                    # ===== 内部モードをエラー状態にする =====
                    print "[mapdb_error]", "procExc NG"
                    return RTC.RTC_ERROR

        return RTC.RTC_OK

        ##
        # 地図データDB制御RTのエラー遷移処理
        #
        # The aborting action when main logic error occurred.
        # former rtc_aborting_entry()
        #
        # @param ec_id target ExecutionContext Id
        #
        # @return RTC::ReturnCode_t
        #
        #
    def onAborting(self, ec_id):
        print "[mapdb_debug]onAborting"

        return RTC.RTC_OK

        ##
        # 地図データDB制御RTのエラー処理
        #
        # The error action in ERROR state
        # former rtc_error_do()
        #
        # @param ec_id target ExecutionContext Id
        #
        # @return RTC::ReturnCode_t
        #
        #
    def onError(self, ec_id):

        return RTC.RTC_OK

        ##
        # 地図データDB制御RTのReset処理
        #
        # The reset action that is invoked resetting
        # This is same but different the former rtc_init_entry()
        #
        # @param ec_id target ExecutionContext Id
        #
        # @return RTC::ReturnCode_t
        #
        #
    def onReset(self, ec_id):
        print "[mapdb_debug]onReset"

        self.versatiInit()

        return RTC.RTC_OK

        ##
        #
        # The state update action that is invoked after onExecute() action
       	# no corresponding operation exists in OpenRTm-aist-0.2.0
        #
        # @param ec_id target ExecutionContext Id
        #
        # @return RTC::ReturnCode_t
        #

        #
    # def onStateUpdate(self, ec_id):
    #
    #   return RTC.RTC_OK

        ##
        #
        # The action that is invoked when execution context's rate is changed
        # no corresponding operation exists in OpenRTm-aist-0.2.0
        #
        # @param ec_id target ExecutionContext Id
        #
        # @return RTC::ReturnCode_t
        #
       	#
    # def onRateChanged(self, ec_id):
    #
    #   return RTC.RTC_OK

# *****************************************************************************
#  サブルーチン
# *****************************************************************************

# ===============================================
#	検証用　ログ
# ===============================================
#     F_LOG = ""
#     DT = datetime.datetime.today()
#     TSTR = DT.strftime('%Y%m%d_%H%M%S')
#     F_LOG_FILE = "c:/workspace/log/" + TSTR + r"_log.txt"


# =============================================================================
#    定数 定義
# =============================================================================
# ===== 内部処理ステータス  =====
    # ===== 内部処理状態 =====
    PROC_STS_IDLE = 0								# // 待機中
    PROC_STS_RUN = 1								# // 処理中
    PROC_STS_ERROR = 2								# // エラー状態

# =========== プロセスID ==========
    PROC_ID_MapDBReqRegistAddData = 1				# // 地図データDB登録処理
    PROC_ID_MapDBReqGetAddDataInfo = 2				# // 地図画像付加データ情報取得処理
    PROC_ID_MapDBReqGetAddData = 3					# // 地図画像付加データ取得処理
    PROC_ID_MapDBReqMakeSynthesisPlanList = 4		# // 合成計画リスト作成処理
    PROC_ID_MapDBReqGetSynthesisPlanList = 5		# // 合成計画リスト取得処理
    PROC_ID_MapDBReqDelSynthesisPlanList = 6		# // 合成計画リスト削除処理

# ===============================================
#    MAPデータ JOSN
# ===============================================
    # ===== MAPデータカラム数 =====
    MAP_DATA_COLUMN_MAX = 11
    # ===== MAPデータ名称(コンソール表示用) =====
    JSON_NM_IMAGE_ID = u"画像ID"
    JSON_NM_GROUP_ID = u"グループID"
    JSON_NM_TILE_NAME = u"タイル名"
    JSON_NM_FOLDER_PATH = u"フォルダパス"
    JSON_NM_ZOOM_LEVEL = u"ズームレベル"
    JSON_NM_X_COORDINATE = u"X座標"
    JSON_NM_Y_COORDINATE = u"Y座標"
    JSON_NM_START_LATITUDE = u"起点緯度"
    JSON_NM_START_LONGITUDE = u"起点経度"
    JSON_NM_END_LATITUDE = u"終点緯度"
    JSON_NM_END_LONGITUDE = u"終点経度"
    JSON_NM_CREATE_DATE = u"作成日"
    JSON_NM_SYNTHESIS_PLAN_NAME = u"合成計画名"

# ===============================================
#    DB関連
# ===============================================
    DB_HOST = "localhost"
    DB_DBNM = "map_data"
    DB_USER = "root"
    DB_PASSWD = ""
    DB_CHRRSET = "utf8"

# ===============================================
#    テーブル関連
# ===============================================
    # ===== 合成計画テーブル =====
    TB01 = "synthesis_plan"
    # ===== 合成計画詳細テーブル =====
    TB02 = "synthesis_plan_detail"

    # ===== 合成計画テーブル カラム =====
    TB01_ITEM_01 = "group_id"
    TB01_ITEM_02 = "create_date"
    TB01_ITEM_03 = "synthesis_plan_name"

    # ===== 合成計画詳細テーブル カラム =====
    TB02_ITEM_01 = "image_id"
    TB02_ITEM_02 = "group_id"
    TB02_ITEM_03 = "tile_name"
    TB02_ITEM_04 = "folder_path"
    TB02_ITEM_05 = "zoom_level"
    TB02_ITEM_06 = "x_coordinate"
    TB02_ITEM_07 = "y_coordinate"
    TB02_ITEM_08 = "start_latitude"
    TB02_ITEM_09 = "start_longitude"
    TB02_ITEM_10 = "end_latitude"
    TB02_ITEM_11 = "end_longitude"
    TB02_ITEM_12 = "create_date"
    TB02_ITEM_13 = "synthesis plan_name"


# =============================================================================
#    変数 定義
# =============================================================================
# ========== IDL 変数定義 （取得パラメータ）==========
    # ===== 地図データDB登録要求ファイル名 =====
    _para_regist_file_name = ""
    # ===== 地図画像付加データ情報取得要 =====
    _para_data_info_group_id = imp_Versatile.GROUP_ID_NON
    _para_data_info_zooml_level = imp_Versatile.ZOOM_LEVEL_DEF
    # ===== 地図画像付加データ取得要求 =====
    _para_data_group_id = imp_Versatile.GROUP_ID_NON
    _para_data_zoom_level = imp_Versatile.ZOOM_LEVEL_DEF
    _para_data_x_coordinate = 0
    _para_data_y_coordinate = 0
    # ===== 合成計画リスト作成要求 =====
    _para_list_make_req = imp_Versatile.SERV_REQ_CLEAR
    # ===== 合成計画リスト取得要求 =====
    _para_list_get_req = imp_Versatile.SERV_REQ_CLEAR
    # ===== 合成計画リスト削除要求 =====
    _para_list_del_groupid = imp_Versatile.GROUP_ID_NON

# ==== DB 接続情報 =====
    _dbconnect = None

# ===== 処理ステータス　
    _proc_sts = PROC_STS_IDLE
# ===== プロセスID =====
    _proc_id = 0 

# ===== MAPデータ取込 =====
    _map_data = ""

# ====== 合成計画リスト作成用 =====
    _plan_list = ""


# =============================================================================
#  処　理：変数初期化処理
# =============================================================================
    def versatiInit(self):
        # ===== パラメータ初期化 =====
        # ===== 地図データDB登録要求ファイル名 =====
        self._para_regist_file_name = ""
        # ===== 地図画像付加データ情報取得要 =====
        self._para_data_info_group_id = imp_Versatile.GROUP_ID_NON
        self._para_data_info_zooml_level = imp_Versatile.ZOOM_LEVEL_DEF
        # ===== 地図画像付加データ取得要求 =====
        self._para_data_group_id = imp_Versatile.GROUP_ID_NON
        self._para_data_zoom_level = imp_Versatile.ZOOM_LEVEL_DEF
        self._para_data_x_coordinate = 0
        self._para_data_y_coordinate = 0
        # ===== 合成計画リスト作成要求 =====
        self._para_list_make_req = imp_Versatile.SERV_REQ_CLEAR
        # ===== 合成計画リスト取得要求 =====
        self._para_list_get_req = imp_Versatile.SERV_REQ_CLEAR
        # ===== 合成計画リスト削除要求 =====
        self._para_list_del_groupid = imp_Versatile.GROUP_ID_NON

        # ==== DB 接続情報 =====
        self._dbconnect = None

        # ===== IDLパラメータ初期化 =====
        self._MapDBReqRegistAddDataProv.clrMapDBReqRegistAddData()
        self._MapDBReqGetAddDataInfoProv.clrMapDBReqGetAddDataInfo()
        self._MapDBReqGetAddDataProv.clrMapDBReqGetAddData()
        self._MapDBReqMakeSynthesisPlanListProv.clrMapDBReqMakeSynthesisPlanList()
        self._MapDBReqDelSynthesisPlanListProv.clrMapDBReqDelSynthesisPlanList()
        self._MapDataDBNoticeProv.clrMapDataDBNotice()


# ============================================================================
#  処　理：日付取得
#  引　数：なし
#  戻り値：現在の日時
# ============================================================================
    def DateTimeGet(self):

        return(datetime.datetime.now().strftime("%Y/%m/%d %H:%M:%S"))


# ============================================================================
#  処　理：日付チェック
#  引　数：(年、月、日)
#  戻り値：成功(True)/失敗(False)
# ============================================================================
    def dateCheck(self, year, month, day):

        try:
            wDate = datetime.date(year, month, day)
            return True

        except Exception as e:
            # ========== 例外処理 ==========
            return False


# ============================================================================
#  処　理：DB接続チェック
#  戻り値：[ret]:成功(True)/失敗(False)
# ============================================================================
    def dbConnectCheck(self):

        ret = False
        connect = None

        try:
            # ===== DB接続 =====
            # connect = MySQLdb.connect(host="localhost", db="*****", user="*****", passwd="*****", charset="utf8")
            connect = MySQLdb.connect(
                host="localhost",
                db="map_data",
                user="root",
                charset="utf8")

            # ==== 戻り値 =====
            if connect == None:
                ret = False
            else:
                self._dbconnect = connect
                ret = True

        except Exception as e:
            # ========== 例外処理 ==========
            print "[mapdb_error]", "Exception", "dbConnectCheck", e.args

            # ===== 戻り値 ====
            ret = False
            connect = None

        finally:
            # ========== 終了処理 ==========
            # ==== 戻り値 =====
            return ret


# =============================================================================
#  処  理：要求チェック
#  戻り値：[ret]:要求あり(True)/要求無なし(False)
# =============================================================================
    def requestCheck(self):
        # ===== 戻り値 =====
        ret = False

        # ===== 処理IDセット 地図データDB登録要求 =====
        if self.mapdbRegistRequestCheck():
            self._proc_id = self.PROC_ID_MapDBReqRegistAddData
            ret = True
        # ===== 処理IDセット 地図画像付加データ情報取得要求 =====
        elif self.getAddDataInfoRequestCheck():
            self._proc_id = self.PROC_ID_MapDBReqGetAddDataInfo
            ret = True
        # ===== 処理IDセット 地図画像付加データ取得要求 =====
        elif self.getAddDataRequestCheck():
            self._proc_id = self.PROC_ID_MapDBReqGetAddData
            ret = True
        # ===== 処理IDセット 合成計画リスト作成要求 =====
        elif self.makeSynthesisPlanRequestCheck():
            self._proc_id = self.PROC_ID_MapDBReqMakeSynthesisPlanList
            ret = True
#         # ===== 処理IDセット 合成計画リスト取得要求 =====
#         elif self.getSynthesisPlanRequestCheck():
#             self._proc_id = self.PROC_ID_MapDBReqGetSynthesisPlanList
#             ret = True
        # ===== 処理IDセット 合成計画リスト削除処要求 =====
        elif self.delSynthesisPlanRequestCheck():
            self._proc_id = self.PROC_ID_MapDBReqDelSynthesisPlanList
            ret = True

        # ===== 戻り値 =====
        return ret


# *****************************************************************************
#       変化チェック処理
# *****************************************************************************

# ============================================================================
#  処　理：地図データDB登録要求 変化チェック
#  戻り値：[ret]:変化あり(True)/変化なし(False)
# ============================================================================
    def mapdbRegistRequestCheck(self):
        # ===== 戻り値 =====
        ret = False

        # ===== 要求確認 =====
        wFileName = self._MapDBReqRegistAddDataProv.GetMapDBReqRegistAddData()

        # ===== 変化なしチェック =====
        if wFileName == "":
            # //初期値のまま変化なし
            ret = False

        # ===== 変化チェック =====
        else:
            # ===== 変化あり =====
            print "[mapdb_debug]GetMapDBReqRegistAddData(),Param1 = %s" % wFileName
            ret = True
            self._para_regist_file_name = wFileName
            self._MapDBReqRegistAddDataProv.clrMapDBReqRegistAddData()

        # ===== 戻り値 =====
        return ret


# ============================================================================
#  処　理：地図画像付加データ情報要求 変化チェック
#  戻り値：[ret]:変化あり(True)/変化なし(False)
# ============================================================================
    def getAddDataInfoRequestCheck(self):
        # ===== 戻り値 =====
        ret = False

        # ===== 要求確認 =====
        wGroupId, wZoomLevel = self._MapDBReqGetAddDataInfoProv.GetMapDBReqGetAddDataInfo()

        # ===== 変化なしチェック =====
        if ((wGroupId == imp_Versatile.GROUP_ID_NON) and
		    (wZoomLevel == imp_Versatile.ZOOM_LEVEL_DEF)):
            # =====初期値のまま変化なし =====
            ret = False

        else:
            print "[mapdb_debug]GetMapDBReqGetAddDataInfo(),Param1 = %d,Param2 = %d" %(wGroupId, wZoomLevel)
            self._para_data_info_group_id = wGroupId
            self._para_data_info_zooml_level = wZoomLevel
            self._MapDBReqGetAddDataInfoProv.clrMapDBReqGetAddDataInfo()
            ret = True

        # ===== 戻り値 =====
        return ret


# ============================================================================
#  処　理：地図画像付加データ要求 変化チェック
#  戻り値：[ret]:変化あり(True)/変化なし(False)
# ============================================================================
    def getAddDataRequestCheck(self):
        # ===== 戻り値 =====
        ret = False

        # ===== 要求確認 =====
        wGroupId, wZoomLevel, wTile_x, wTile_y = self._MapDBReqGetAddDataProv.GetMapDBReqGetAddData()

        # ===== 変化なしチェック =====
        if ((wGroupId == imp_Versatile.GROUP_ID_NON) and
            (wZoomLevel == imp_Versatile.ZOOM_LEVEL_DEF) and
            (wTile_x) == 0 and 
            (wTile_y == 0)):
            # =====初期値のまま変化なし =====
            ret = False
        else:
            print "[mapdb_debug]GetMapDBReqGetAddData(),Param1 = %d,Param2 = %d,Param3 = %d,Param4 = %d" %(wGroupId, wZoomLevel, wTile_x, wTile_y)
            self._para_data_group_id = wGroupId
            self._para_data_zoom_level = wZoomLevel
            self._para_data_x_coordinate = wTile_x
            self._para_data_y_coordinate = wTile_y
            self._MapDBReqGetAddDataProv.clrMapDBReqGetAddData()
            ret = True

        # ===== 戻り値 =====
        return ret


# ============================================================================
#  処　理：合成計画リスト作成要求 変化チェック
#  戻り値：[ret]:変化あり(True)/変化なし(False)
# ============================================================================
    def makeSynthesisPlanRequestCheck(self):
        # ===== 戻り値 =====
        ret = False

        # ===== 要求確認 =====
        wListMakeReq = self._MapDBReqMakeSynthesisPlanListProv.GetMapDBReqMakeSynthesisPlanList()

        if wListMakeReq == imp_Versatile.SERV_REQ_SET:
            print "[mapdb_debug]GetMapDBReqMakeSynthesisPlanList(),Param1 = %d" % wListMakeReq
            ret = True
            self._para_list_make_req = wListMakeReq
            self._MapDBReqMakeSynthesisPlanListProv.usSetMapDBReqMakeSynthesisPlanList(
                imp_Versatile.SERV_REQ_CLEAR)

        # ===== 戻り値 =====
        return ret


# ============================================================================
#  処　理：合成計画リスト取得要求 変化チェック
#  戻り値：[ret]:変化あり(True)/変化なし(False)
# ============================================================================
    def getSynthesisPlanRequestCheck(self):
        # ===== 戻り値 =====
        ret = False

        # ===== 要求確認 =====
        wListGetReq = self._MapDBReqGetSynthesisPlanListProv.GetMapDBReqGetSynthesisPlanList()

        if wListGetReq == imp_Versatile.SERV_REQ_SET:
            print "[mapdb_debug]GetMapDBReqGetSynthesisPlanList(),Param1 = %d" % wListGetReq
            ret = True
            self._para_list_get_req = wListGetReq
            self._MapDBReqGetSynthesisPlanListProv.usSetMapDBReqGetSynthesisPlanList(
                imp_Versatile.SERV_REQ_CLEAR)

        # ===== 戻り値 =====
        return ret


# ============================================================================
#  処　理：合成計画リスト削除要求 変化チェック
#  戻り値：[ret]:変化あり(True)/変化なし(False)
# ============================================================================
    def delSynthesisPlanRequestCheck(self):
        # ===== 戻り値 =====
        ret = False

        # ===== 要求確認 =====
        wGroupId = self._MapDBReqDelSynthesisPlanListProv.GetMapDBReqDelSynthesisPlanList()

        # ===== 変化なしチェック =====
        if wGroupId == imp_Versatile.GROUP_ID_NON:
            # ===== 初期値のまま変化なし =====
            ret = False
        # ===== 変化チェック =====
        else:
            # ===== 変化あり =====
            print "[mapdb_debug]GetMapDBReqDelSynthesisPlanList(),Param1 = %d" % wGroupId
            ret = True
            self._para_list_del_groupid = wGroupId
            self._MapDBReqDelSynthesisPlanListProv.clrMapDBReqDelSynthesisPlanList()

        # ===== 戻り値 =====
        return ret


# ****************************************************************************
#       処 理
#
# ****************************************************************************

# ============================================================================
#  処　理：処理実行
#  戻り値：[ret]:変化あり(True)/変化なし(False)
# ============================================================================
    def procExc(self):
        # ===== 戻り値 =====
        ret = False

        # ===== 地図データDB登録 処理 =====
        if self._proc_id == self.PROC_ID_MapDBReqRegistAddData:
            ret = self.procMapDBReqRegistAddData()
        # ===== 地図画像付加データ情報取得 処理 =====
        elif self._proc_id == self.PROC_ID_MapDBReqGetAddDataInfo:
            ret = self.procMapDBReqGetAddDataInfo()
        # ===== 地図画像付加データ取得 処理 =====
        elif self._proc_id == self.PROC_ID_MapDBReqGetAddData:
            ret = self.procMapDBReqGetAddData()
        # ===== 合成画リスト作成 処理 =====
        elif self._proc_id == self.PROC_ID_MapDBReqMakeSynthesisPlanList:
            ret = self.procMapDBReqMakeSynthesisPlanList()
#         # ===== 合成画リスト取得 処理 =====
#         elif self._proc_id == self.PROC_ID_MapDBReqGetSynthesisPlanList:
#             ret = self.procMapDBReqGetSynthesisPlanList()
        # ===== 合成画リスト削除 処理 =====
        elif self._proc_id == self.PROC_ID_MapDBReqDelSynthesisPlanList:
            ret = self.procMapDBReqDelSynthesisPlanList()
        else:
            print "[mapdb_error]", "wModuleID", u"プロセスIDエラー", self._proc_id

        # ===== 戻り値 =====
        return ret


# ============================================================================
#  処　理：地図データDB登録 処理
#  引　数：なし
#  戻り値：[ret]:成功(True)/失敗(False)
# ============================================================================
    def procMapDBReqRegistAddData(self):
        ret = False

        # ===== 処理状態セット =====
        self._proc_sts = self.PROC_STS_RUN

        # ===== 地図データ取込  =====
        f = open(self._para_regist_file_name, "r")
        self._map_data = json.load(f)
        f.close()
        # ===== 地図整合性チェック =====
        if self.mapDataMismatchCheck(self._map_data):

            # ===== 地図DB登録処理 =====
            if self.mapDBRegist(self._map_data):

                # ===== 合成計画リスト作成取得 =====
                ret, jsonString, listCnt = self.makeSynthesisPlanList()

                # ===== データセット =====
                if ret and listCnt > 0:
                    # ===== json → 配列にセット =====
                    jsonrd = json.loads(jsonString)
                    dataBuffer = []
                    for row in jsonrd:
                        value = str(row)
                        dataBuffer.append(value)

                    # ===== データポートにセット =====
                    if len(dataBuffer) > 0 :
                        self._d_outSynthesisPlanList.data = dataBuffer
                        self._outSynthesisPlanListOut.write()
                        print "mapdata set OK"
                    # ===== 戻り値セット =====
                    ret = True

        # ===== 終了処理 DB完了通知セット =====
        if ret:
            # ===== 処理OK =====
            print "[mapdb_debug]procMapDBReqRegistAdd OK,Notice = %d, Param = %d" %(imp_Versatile.MAPDB_REGIST_SUCCESS, listCnt)
            self._MapDataDBNoticeProv.usSetMapDataDBNotice(
                imp_Versatile.MAPDB_REGIST_SUCCESS, listCnt)
        else:
            # ===== 処理NG =====
            print "[mapdb_debug]procMapDBReqRegistAdd NG,Notice = %d, Param = %d" %(imp_Versatile.MAPDB_REGIST_ERROR, 0)
            self._MapDataDBNoticeProv.usSetMapDataDBNotice(
                imp_Versatile.MAPDB_REGIST_ERROR, 0)

        # ===== 処理状態をIDLEに設定 =====
        self._proc_sts = self.PROC_STS_IDLE

        # ===== 戻り値 =====
        return ret


# ============================================================================
#  処　理：地図画像付加データ情報取得 処理
#  引　数：なし
#  戻り値：[ret]:成功(True)/失敗(False)
# ============================================================================
    def procMapDBReqGetAddDataInfo(self):
        ret = False

        # ===== 処理状態セット =====
        self._proc_sts = self.PROC_STS_RUN

        # ===== 地図画像付加データ情報取得 =====
        jsonString = ""
        ret, jsonString, listCnt = self.getAddDataInfo(
                                    self._para_data_info_group_id,
                                    self._para_data_info_zooml_level)

        # ===== データセット =====
        if ret and listCnt > 0:
            # ===== json →	　配列にセット　=====
            jsonrd = json.loads(jsonString)

            dataBuffer = []
            for row in jsonrd:
                value = str(row)
                dataBuffer.append(value)

            # ===== データポートにセット =====
            if len(dataBuffer) > 0 :
                self._d_outMapAdditinalInfo.data = str(dataBuffer)
                self._outMapAdditinalInfoOut.write()

            # ===== 戻り値 =====
            ret = True

        # ===== 終了処理 DB完了通知セット =====
        if ret:
            # ===== 処理OK =====
            print "[mapdb_debug]procMapDBReqGetAddDataInfo OK,Notice = %d, Param = %d" %(imp_Versatile.MAPDB_GET_ADD_INFO_SUCCESS, listCnt)
            self._MapDataDBNoticeProv.usSetMapDataDBNotice(
                imp_Versatile.MAPDB_GET_ADD_INFO_SUCCESS, listCnt)
        else:
            # ===== 処理NG =====
            print "[mapdb_debug]procMapDBReqGetAddDataInfo NG,Notice = %d, Param = %d" %(imp_Versatile.MAPDB_GET_ADD_INFO_ERROR, 0)
            self._MapDataDBNoticeProv.usSetMapDataDBNotice(
                imp_Versatile.MAPDB_GET_ADD_INFO_ERROR, 0)

        # ===== 処理状態をIDLEに設定 =====
        self._proc_sts = self.PROC_STS_IDLE

        # ===== 戻り値 =====
        return ret

# ============================================================================
#  処　理：地図画像付加データ取得 処理
#  引　数：なし
#  戻り値：[ret]:成功(True)/失敗(False)
# ============================================================================
    def procMapDBReqGetAddData(self):
        ret = False

        # ===== 処理状態セット =====
        self._proc_sts = self.PROC_STS_RUN

        # ===== 地図画像付加データ取得 =====
        jsonString = ""
        ret, jsonString, listCnt = self.getAddData(
                                                    self._para_data_group_id,
                                                    self._para_data_zoom_level,
                                                    self._para_data_x_coordinate,
                                                    self._para_data_y_coordinate)

        # ===== データセット =====
        if ret and listCnt > 0:
            # ===== jsonを配列にセット　=====
            jsonrd = json.loads(jsonString)
            dataBuffer = []
            for row in jsonrd:
                value = str(row)
                dataBuffer.append(value)

            # ===== データポートにセット =====
            self._d_outMapAdditinalData.data = str(dataBuffer)
            self._outMapAdditinalDataOut.write()

            # ===== 戻り値セット =====
            ret = True

        # ===== 終了処理 DB完了通知セット=====
        if ret:
            # ===== 処理OK =====
            print "[mapdb_debug]procMapDBReqGetAddData OK,Notice = %d, Param = %d" %(imp_Versatile.MAPDB_GET_ADD_DATA_SUCCESS, listCnt)
            self._MapDataDBNoticeProv.usSetMapDataDBNotice(
                imp_Versatile.MAPDB_GET_ADD_DATA_SUCCESS, listCnt)
        else:
            # ===== 処理NG =====
            print "[mapdb_debug]procMapDBReqGetAddData NG,Notice = %d, Param = %d" %(imp_Versatile.MAPDB_GET_ADD_DATA_ERROR, 0)
            self._MapDataDBNoticeProv.usSetMapDataDBNotice(
                imp_Versatile.MAPDB_GET_ADD_DATA_ERROR, 0)

        # ===== 処理状態をIDLEに設定 =====
        self._proc_sts = self.PROC_STS_IDLE

        # ===== 戻り値 =====
        return ret


# ============================================================================
#  処　理：合成計画リスト作成 処理
#  引　数：なし
#  戻り値：[ret]:成功(True)/失敗(False)
# ============================================================================
    def procMapDBReqMakeSynthesisPlanList(self):
        ret = False

        # ===== 処理状態セット =====
        self._proc_sts = self.PROC_STS_RUN

        # ===== 合成計画リスト作成 =====
        ret, jsonString, listCnt = self.makeSynthesisPlanList()

        # ===== jsonStringセット =====
        #self._plan_list = jsonString

        # ===== 合成計画リスト取得 =====
        if ret and listCnt > 0:
            jsonrd = json.loads(jsonString)
            dataBuffer = []
            for row in jsonrd:
                value = str(row)
                dataBuffer.append(value)

            # ===== データポート　セット =====
            self._d_outSynthesisPlanList.data = dataBuffer
            self._outSynthesisPlanListOut.write()

            # ===== 戻り値セット =====
            ret = True

        # ===== 終了処理 DB完了通知セット =====
        if ret:
            # ===== 処理OK =====
            print "[mapdb_debug]procMapDBReqMakeSynthesisPlanList OK,Notice = %d, Param = %d" %(imp_Versatile.MAPDB_MAKE_LIST_SUCCESS, listCnt)
            self._MapDataDBNoticeProv.usSetMapDataDBNotice(
                imp_Versatile.MAPDB_MAKE_LIST_SUCCESS, listCnt)
        else:
            # ===== 処理NG =====
            print "[mapdb_debug]procMapDBReqMakeSynthesisPlanList NG,Notice = %d, Param = %d" %(imp_Versatile.MAPDB_MAKE_LIST_ERROR, 0)
            self._MapDataDBNoticeProv.usSetMapDataDBNotice(
                imp_Versatile.MAPDB_MAKE_LIST_ERROR, 0)

        # ===== 処理状態をIDLEに設定 =====
        self._proc_sts = self.PROC_STS_IDLE

        # ===== 戻り値 =====
        return ret


# ============================================================================
#  処　理：合成計画リスト取得 処理
#  引　数：なし
#  戻り値：[ret]:成功(True)/失敗(False)
# ============================================================================
    def procMapDBReqGetSynthesisPlanList(self):
        ret = False

        # ===== 処理状態セット =====
        self._proc_sts = self.PROC_STS_RUN

        # ===== 合成計画リスト取得 =====
        jsonString = self._plan_list

        # ===== jsonを配列にセット =====
        jsonrd = json.loads(jsonString)
        dataBuffer = []
        for row in jsonrd:
            value = str(row)
            dataBuffer.append(value)

        # ===== 取得件数セット =====
        listCnt = len(dataBuffer)

        # ===== データポート　セット =====
        self._d_outSynthesisPlanList.data = dataBuffer
        self._outSynthesisPlanListOut.write()

        # ===== 戻り値セット =====
        ret = True

        # ===== 終了処理 DB完了通知セット=====
        if ret:
            # ===== 処理OK =====
            print "[mapdb_debug]procMapDBReqGetSynthesisPlanList OK,Notice = %d, Param = %d" %(imp_Versatile.MAPDB_GET_LIST_SUCCESS, listCnt)
            self._MapDataDBNoticeProv.usSetMapDataDBNotice(
                imp_Versatile.MAPDB_GET_LIST_SUCCESS, listCnt)
        else:
            # ===== 処理NG =====
            print "[mapdb_debug]procMapDBReqGetSynthesisPlanList NG,Notice = %d, Param = %d" %(imp_Versatile.MAPDB_GET_LIST_ERROR, 0)
            self._MapDataDBNoticeProv.usSetMapDataDBNotice(
                imp_Versatile.MAPDB_GET_LIST_ERROR, 0)

        # ===== 処理状態をIDLEに設定 =====
        self._proc_sts = self.PROC_STS_IDLE

        # ===== 戻り値 =====
        return ret


# ============================================================================
#  処　理：合成計画リスト削除 処理
#  引　数：なし
#  戻り値：[ret]:成功(True)/失敗(False)
# ============================================================================
    def procMapDBReqDelSynthesisPlanList(self):
        ret = False

        # ===== 処理状態セット =====
        self._proc_sts = self.PROC_STS_RUN

        # ===== 合成計画リスト削除処理 =====
        ret, listCnt = self.delSynthesisPlanList(self._para_list_del_groupid)

        # ===== 合成計画リスト作成取得処理 =====
        ret, jsonString, listCnt = self.makeSynthesisPlanList()

        # ===== データセット =====
        if ret and listCnt > 0:
            # ===== json →    　配列にセット　=====
            jsonrd = json.loads(jsonString)

            dataBuffer = []
            for row in jsonrd:
                value = str(row)
                dataBuffer.append(value)

            # ===== データポートにセット =====
            if len(dataBuffer) > 0 :
                self._d_outSynthesisPlanList.data = dataBuffer
                self._outSynthesisPlanListOut.write()

            # ===== 戻り値セット =====
            ret = True

        # ===== 終了処理 DB完了通知セット=====
        if ret:
            # ===== 処理OK =====
            print "[mapdb_debug]procMapDBReqDelSynthesisPlanList OK,Notice = %d, Param = %d" %(imp_Versatile.MAPDB_DEL_LIST_SUCCESS, listCnt)
            self._MapDataDBNoticeProv.usSetMapDataDBNotice(
                imp_Versatile.MAPDB_DEL_LIST_SUCCESS, listCnt)
        else:
            # ===== 処理NG =====
            print "[mapdb_debug]procMapDBReqDelSynthesisPlanList NG,Notice = %d, Param = %d" %(imp_Versatile.MAPDB_DEL_LIST_ERROR, 0)
            self._MapDataDBNoticeProv.usSetMapDataDBNotice(
                imp_Versatile.MAPDB_DEL_LIST_ERROR, 0)

        # ===== 処理状態をIDLEに設定 =====
        self._proc_sts = self.PROC_STS_IDLE

        # ===== 戻り値 =====
        return ret


# ============================================================================
#  処　理：地図データ不整合チェック
#  引  数：[registFile]地図データ
#  戻り値：[ret]:成功(True)/失敗(False)
# ============================================================================
    def mapDataMismatchCheck(self, registFile):
        ret = False
        sItemNm = ""
        sItem = ""

        try:
            # ========== [registFile]がなくなるまで処理を繰り返す ==========
            for row in registFile:
                # ===== 地図データ列数チェック =====
                if len(registFile[row]) != self.MAP_DATA_COLUMN_MAX:
                    sItemNm = u"地図データフォーマット不正です"
                    sItem = registFile
                    break

                # ===== タイル名 =====
                str0 = registFile[row][imp_Versatile.MAPDATA_TILE_NAME]
                sItemNm = self.JSON_NM_TILE_NAME
                sItem = str0
                if ((len(str0.encode("shift_jis"))) < 1 or
                    (len(str0.encode("shift_jis")) > imp_Versatile.MAPDATA_TILE_NAME_LENGTH)):
                    break

                # ===== フォルダパス =====
                str1 = registFile[row][imp_Versatile.MAPDATA_FOLDER_PATH]
                sItemNm = self.JSON_NM_FOLDER_PATH
                sItem = str1
                if ((len(str1.encode("shift_jis"))) < 1 or 
                    (len(str1.encode("shift_jis")) > imp_Versatile.MAPDATA_FOLDER_PATH_LENGTH )):
                    break

                # ===== ズームレベル =====
                sItemNm = self.JSON_NM_ZOOM_LEVEL
                sItem = registFile[row][imp_Versatile.MAPDATA_ZOOM_LEVEL]
                if ((int(registFile[row][imp_Versatile.MAPDATA_ZOOM_LEVEL]) < imp_Versatile.ZOOM_LEVEL_MIN) or 
                        (int(registFile[row][imp_Versatile.MAPDATA_ZOOM_LEVEL]) > imp_Versatile.ZOOM_LEVEL_MAX)):
                    break

                # ===== X座標 =====
                sItemNm = self.JSON_NM_X_COORDINATE
                sItem = registFile[row][imp_Versatile.MAPDATA_TILECODE_X]
                if (not(str(registFile[row][imp_Versatile.MAPDATA_TILECODE_X]).replace(".", "").isdigit()) or
                        (registFile[row][imp_Versatile.MAPDATA_TILECODE_X] < 0)):
                    break

                # ===== Y座標 =====
                sItemNm = self.JSON_NM_Y_COORDINATE
                sItem = registFile[row][imp_Versatile.MAPDATA_TILECODE_Y]
                if (not(str(registFile[row][imp_Versatile.MAPDATA_TILECODE_Y]).replace(".", "").isdigit()) or 
                        (registFile[row][imp_Versatile.MAPDATA_TILECODE_Y] < 0)):
                    break

                # ===== 起点緯度 =====
                sItemNm = self.JSON_NM_START_LATITUDE
                sItem = registFile[row][imp_Versatile.MAPDATA_START_LATITUDE]
                if (not(str(registFile[row][imp_Versatile.MAPDATA_START_LATITUDE]).replace(".", "").isdigit()) or
                        (registFile[row][imp_Versatile.MAPDATA_START_LATITUDE] < imp_Versatile.LATITUBE_NIN) or 
                        (registFile[row][imp_Versatile.MAPDATA_START_LATITUDE] > imp_Versatile.LATITUBE_MAX)):
                    break

                # ===== 起点経度 =====
                sItemNm = self.JSON_NM_START_LONGITUDE
                sItem = registFile[row][imp_Versatile.MAPDATA_START_LONGITUDE]
                if (not(str(registFile[row][imp_Versatile.MAPDATA_START_LONGITUDE]).replace(".", "").isdigit()) or
                        (registFile[row][imp_Versatile.MAPDATA_START_LONGITUDE] < imp_Versatile.LONGITUDE_MIN) or 
                        (registFile[row][imp_Versatile.MAPDATA_START_LONGITUDE] > imp_Versatile.LONGITUDE_MAX)):
                    break

                # ===== 終点緯度 =====
                sItemNm = self.JSON_NM_END_LATITUDE
                sItem = registFile[row][imp_Versatile.MAPDATA_END_LATITUDE]
                if (not(str(registFile[row][imp_Versatile.MAPDATA_END_LATITUDE]).replace(".", "").isdigit()) or
                        (registFile[row][imp_Versatile.MAPDATA_END_LATITUDE] < imp_Versatile.LATITUBE_NIN) or 
                        (registFile[row][imp_Versatile.MAPDATA_END_LATITUDE] > imp_Versatile.LATITUBE_MAX)):
                    break

                # ===== 終点経度 =====
                sItemNm = self.JSON_NM_END_LONGITUDE
                sItem = registFile[row][imp_Versatile.MAPDATA_END_LONGITUDE]

                if (not(str(registFile[row][imp_Versatile.MAPDATA_END_LONGITUDE]).replace(".", "").isdigit()) or
                        (registFile[row][imp_Versatile.MAPDATA_END_LONGITUDE] < imp_Versatile.LONGITUDE_MIN) or 
                        (registFile[row][imp_Versatile.MAPDATA_END_LONGITUDE] > imp_Versatile.LONGITUDE_MAX)):
                    break

                # ===== 作成日 =====
                sItemNm = self.JSON_NM_CREATE_DATE
                sItem = registFile[row][imp_Versatile.MAPDATA_CREATE_DATE]
                wDate = registFile[row][imp_Versatile.MAPDATA_CREATE_DATE]

                wYear = int(wDate[0:4])
                wMonth = int(wDate[4:6])
                wDay = int(wDate[6:8])

                if (len(wDate) != 8) or (self.dateCheck(wYear, wMonth, wDay)== False):
                    break

                # ===== 合成計画名 =====
                str11 = registFile[row][imp_Versatile.MAPDATA_PLAN_NAME]
                sItemNm = self.JSON_NM_SYNTHESIS_PLAN_NAME
                sItem = str11
                if ((len(str11.encode("shift_jis")) < 1) or 
                    (len(str11.encode("shift_jis")) > imp_Versatile.MAPDATA_PLANNAME_LENGTH)):
                    break
                else:
                    #===== 戻り値セット =====
                    ret = True

        except Exception as e:
            # ========== 例外処理 ==========
            print "[mapdb_error]", "Exception", sys._getframe().f_code.co_name, e.args

            #===== 戻り値セット =====
            ret = False

        finally:
            # ========== 終了処理 ==========
            if ret:
                print "[mapdb_debug]", "mapDataMismatchCheck OK"
            else:
                print "[mapdb_error]", "mapDataMismatchCheck NG", sItemNm, sItem

            # ===== 戻り値 =====
            return ret


# ============================================================================
#  処　理：地図データDB登録
#  引　数：[mapData]地図データ
#  戻り値：[ret]:成功(True)/失敗(False)
# ============================================================================
    def mapDBRegist(self, mapData):

        ret = False

        try:
            # ===== DB登録 計画リスト =====
            if self.dbRegistSynthesisPlan(mapData):
                #===== 戻り値セット =====
                ret = True

        except Exception as e:
            # ========== 例外処理 ==========
            print "[mapdb_error]", "Exception", sys._getframe().f_code.co_name, e.args

            #===== 戻り値セット =====
            ret = False

        finally:
            # ========== 終了処理 ==========
            # ===== 戻り値 =====
            return ret


# ============================================================================
#  処　理：DB登録 [合成計画リスト],[合成計画リスト詳細]
#  引  数：[mapData]地図登録データ
#  戻り値：[ret:成功(True)/失敗(False)
#  備　考：DB接続は呼びだし元で対応するため、接続正常時が前提
# ============================================================================
    def dbRegistSynthesisPlan(self, mapData):
        ret = False
        wGroup_Id = 0

        try:
            # ===== カーソール設定　=====
            cursor0 = self._dbconnect.cursor()
            cursor1 = self._dbconnect.cursor()
            cursor2 = self._dbconnect.cursor()
            cursor3 = self._dbconnect.cursor()
            cursor4 = self._dbconnect.cursor()

            # =======================================================
            #		mapDataがなくなるまで繰り返す
            # =======================================================
            for row in mapData:
                # ========== [合成計画リスト]存在チェック [合成計画名]、[作成日]で検索 ==========
                wSynthesis_Plan_Name = mapData[row][imp_Versatile.MAPDATA_PLAN_NAME]
                wCreate_Date = mapData[row][imp_Versatile.MAPDATA_CREATE_DATE]

                ret, wGroup_Id = self.synthesisPlanGroupIdExistCheck(
                    cursor0, wSynthesis_Plan_Name, wCreate_Date)

                if ret == False:
                    # ===== forを抜ける =====
                    break

                # ========== 上記検索で0件の場合 グループID取得 ==========
                if wGroup_Id == 0:
                    ret, wGroup_Id = self.synthesisPlanGroupIdGet(cursor1)
                    if ret == False:
                        # ===== forを抜ける =====
                        break

                    # =========================================================
                    #    [合成計画リスト]テーブル登録
                    # =========================================================
                    # ===== [合成計画リスト]件数確認 =====
                    ret, planCnt = self.synthesisPlanNumberChek()
                    if ret == False:
                        # ===== forを抜ける =====
                        break

                    # ===== 計画リストDB追加 SQL文生成 =====
                    sql = ""
                    sql = sql + "insert into synthesis_plan"
                    sql = sql + " (group_id ,create_date ,synthesis_plan_name)"
                    sql = sql + "  values(%s, %s, %s)"

                    # ===== 計画リストDB追加 =====
                    cursor3.execute(sql, (wGroup_Id, 
                                        mapData[row][imp_Versatile.MAPDATA_CREATE_DATE], 
                                        mapData[row][imp_Versatile.MAPDATA_PLAN_NAME]))

                else:
                    # ===== メッセージ表示 =====
                    print u"[mapdb_messege]", u"合成計画リストに登録済です", wSynthesis_Plan_Name, wCreate_Date

                # =================================================================
                #    計画リスト詳細」テーブル登録
                # =================================================================
                #===== sql文生成 =====
                sql = ""
                sql = sql + "insert into synthesis_plan_detail"
                sql = sql + " ("
                sql = sql + "  group_id"
                sql = sql + " ,tile_name"
                sql = sql + " ,folder_path"
                sql = sql + " ,zoom_level"
                sql = sql + " ,x_coordinate"
                sql = sql + " ,y_coordinate"
                sql = sql + " ,start_latitude"
                sql = sql + " ,start_longitude"
                sql = sql + " ,end_latitude"
                sql = sql + " ,end_longitude"
                sql = sql + " ,create_date"
                sql = sql + " ,synthesis_plan_name"
                sql = sql + " ) "
                sql = sql + u" values(%s, %s, %s, %s, %s, %s, %s, %s, %s, %s"
                sql = sql + u", %s, %s)"

                # ===== 「合成計画リスト詳細」テーブルDB登録 =====
                cursor4.execute(sql, (wGroup_Id, 
                                      mapData[row][imp_Versatile.MAPDATA_TILE_NAME],
                                      mapData[row][imp_Versatile.MAPDATA_FOLDER_PATH],
                                      mapData[row][imp_Versatile.MAPDATA_ZOOM_LEVEL],
                                      mapData[row][imp_Versatile.MAPDATA_TILECODE_X],
                                      mapData[row][imp_Versatile.MAPDATA_TILECODE_Y],
                                      mapData[row][imp_Versatile.MAPDATA_START_LATITUDE],
                                      mapData[row][imp_Versatile.MAPDATA_START_LONGITUDE],
                                      mapData[row][imp_Versatile.MAPDATA_END_LATITUDE],
                                      mapData[row][imp_Versatile.MAPDATA_END_LONGITUDE],
                                      mapData[row][imp_Versatile.MAPDATA_CREATE_DATE],
                                      mapData[row][imp_Versatile.MAPDATA_PLAN_NAME])
                                )



            # ===== コミット =======
            self._dbconnect.commit()

            # ===== カーソルクローズ =====
            cursor1.close()
            cursor2.close()
            cursor3.close()
            cursor4.close()

            # ===== 戻り値セット =====
            ret = True

        except Exception as e:
            # ========== 例外処理 ==========
            print "[mapdb_error]", "Exception", sys._getframe().f_code.co_name, e.args

            # ===== ロールバック =======
            self._dbconnect.rollback()

            # ===== 戻り値セット =====
            ret = False

        finally:
            # ========== 終了処理 ==========
            # ===== 戻り値 =====
            return ret


# ============================================================================
#  処　理：[合成計画リスト]テーブル件数確認
#  引　数：[connect]DB接続情報
#  戻り値：[ret]:成功(True)/失敗(False), [esult[0]]:件数
# ============================================================================
    def synthesisPlanNumberChek(self):
        ret = False

        try:
            cursor = self._dbconnect.cursor()
            # ===== [計画リスト]件数確認 =====
            sql = ""
            sql = " select count(*) as cnt from synthesis_plan"
            cursor.execute(sql)
            # ===== 結果をセット配列化(1件のみ取得) =====
            result = cursor.fetchone()

            # ==== 戻り値セット =====
            ret = True
            # ==== 戻り値 =====
            return (ret, result[0])

        except Exception as e:
            # ========== 例外処理 ==========
            print "[mapdb_error]", "Exception", sys._getframe().f_code.co_name, e.args

            # ===== 戻り値 =====
            return (ret, 0)


# ============================================================================
#  処　理：[合成計画リスト]テーブル　グループID存在チェック
#  引　数：[cursor1]:接続情報, [synthesis_plan_name]:合成計画名, [create_date]:作成日
#  戻り値：[ret]:成功(True)/失敗(False), [group_id]:グループID
# ============================================================================
    def synthesisPlanGroupIdExistCheck(self, cursor1, synthesis_plan_name, create_date):
        ret = False

        try:
            # ===== SQL文生成 =====
            # ===== [計画リスト]テーブルより[合成計画名][作成日]で取得 =====
            sql = ""
            sql = sql + " select group_id, synthesis_plan_name, create_date "
            sql = sql + " from synthesis_plan"           
            sql = sql + " where synthesis_plan_name = '%s' and create_date = '%s' "

            # ===== sql実行 =====
            cursor1.execute(sql % (synthesis_plan_name, create_date))

            # ===== 結果をセット配列化(1件のみ取得)=====
            result1 = cursor1.fetchone()

            # ===== グループＩＤセット =====
            if cursor1.rowcount == 0:
                group_id = 0
            else:
                group_id = result1[0]

            # ===== 戻り値セット =====
            ret = True

            # ===== 戻り値 =====
            return (ret, group_id)

        except Exception as e:
            # ========== 例外処理 ==========
            print "[mapdb_error]", "Exception", sys._getframe().f_code.co_name, e.args

            # ===== 戻り値 =====
            return (ret, 0)


# ============================================================================
#  処　理：[合成計画リスト]グループID取得
#  引　数：[cursor2]:接続情報
#  戻り値：[ret]:成功(True)/失敗(False),[group_id]:グループID
# ============================================================================
    def synthesisPlanGroupIdGet(self, cursor2):
        ret = False
        group_id = 0

        try:
            # ===== SQL文生成 =====
            sql = ""
            sql = sql + " select max(group_id) + 1  as cnt from synthesis_plan "

            # ===== sql実行 「計画リスト」グループIDの取得 =====
            cursor2.execute(sql)

            # ===== 結果をセット配列化 (1件のみ取得)=====
            result2 = cursor2.fetchone()

            # ===== グループID 取得 =====
            if result2[0] == None:
                group_id = 1
            else:
                group_id = result2[0]

            # ===== 戻り値セット =====
            ret = True

            # ===== 戻り値 =====
            return (ret, group_id)

        except Exception as e:
            # ========== 例外処理 ==========
            print "[mapdb_error]", u"Exception", sys._getframe().f_code.co_name, e.args

            # ===== 戻り値 =====
            return (ret, 0)


# ============================================================================
#  処　理：地図画像付加データ情報取得
#  引　数：[ulGroupId]:グループID, [ulZoomLevel]:ズームレベル
#  戻り値：[ret]成功(True)/失敗(False),[jsonstring]:作成データ,[dCnt]:取得件数
# ============================================================================
    def getAddDataInfo(self, ulGroupId, ulZoomLevel):
        ret = False
        jsonString = ""
        dCnt = 0

        try:
            # ===== カーソール設定　=====
            cursor = self._dbconnect.cursor()

            # =============================================
            # ===== X座標sql文生成 =====#
            sql = ""
            sql = sql + " select t1.group_id, "
            sql = sql + "        t1.zoom_level, "
            sql = sql + "        count(t2.x_coordinate) as xcnt,"
            sql = sql + "        t1.y_coordinate "
            sql = sql + " from (select group_id,"
            sql = sql + "              zoom_level,"
            sql = sql + "              min(y_coordinate) as y_coordinate " 
            sql = sql + "       from synthesis_plan_detail "
            sql = sql + "       where group_id = %s and zoom_level = %s ) t1"
            sql = sql + " inner join synthesis_plan_detail t2 "
            sql = sql + " on t1.group_id = t2.group_id and "
            sql = sql + "    t1.zoom_level = t2.zoom_level and "
            sql = sql + "    t1.y_coordinate = t2.y_coordinate "

            # ===== sql実行 ====
            cursor.execute(sql % (ulGroupId, ulZoomLevel))

            # ===== データ件数 =====
            dCnt = cursor.rowcount

            # ===== 結果をセット配列化 =====
            result = cursor.fetchall()

            # ===== 取得データ退避 =====
            for row in result:
                wGROUP_ID = row[0]
                wZOOM_LEVEL = row[1]
                wTILE_NUM_X = row[2]
                wTILE_BASECODE_Y = row[3]

            # =============================================
            # ===== Y座標sql文生成 =====
            sql = ""
            sql = sql + " select t1.group_id, "
            sql = sql + "        t1.zoom_level, "
            sql = sql + "        count(t2.y_coordinate) as ycnt,"
            sql = sql + "        t1.x_coordinate "
            sql = sql + " from (select group_id,"
            sql = sql + "              zoom_level,"
            sql = sql + "              min(x_coordinate) as x_coordinate " 
            sql = sql + "       from synthesis_plan_detail "
            sql = sql + "       where group_id = %s and zoom_level = %s ) t1"
            sql = sql + " inner join synthesis_plan_detail t2 "
            sql = sql + " on t1.group_id = t2.group_id and "
            sql = sql + "    t1.zoom_level = t2.zoom_level and "
            sql = sql + "    t1.x_coordinate = t2.x_coordinate "

            # ===== sql実行 ====
            cursor.execute(sql % (ulGroupId, ulZoomLevel))

            # ===== データ件数 =====
            dCnt = cursor.rowcount

            # ===== 結果をセット配列化 =====
            result = cursor.fetchall()

            # ===== 取得データ退避 =====
            for row in result:
                wTILE_NUM_Y = row[2]
                wTILE_BASECODE_X = row[3]

            # =============================================
            # ===== ズームレベル =====
            sql = ""
            sql = sql + " select group_id, "
            sql = sql + "        zoom_level "
            sql = sql + " from synthesis_plan_detail "
            sql = sql + " where group_id = %s "
            sql = sql + " group by zoom_level "

            # ===== sql実行 ====
            cursor.execute(sql % (ulGroupId))

            # ===== 結果をセット配列化 =====
            result = cursor.fetchall()

            w_MASK_ZOOM = 0x00000000
            wZOOM= 0
            for row in result:
                wZOOM = row[1]

                if wZOOM == imp_Versatile.ZOOM_LEVEL_18:
                    w_MASK_ZOOM = (w_MASK_ZOOM  | imp_Versatile.MASK_ZOOM_18)
                elif wZOOM == imp_Versatile.ZOOM_LEVEL_19:
                    w_MASK_ZOOM = (w_MASK_ZOOM | imp_Versatile.MASK_ZOOM_19)
                elif wZOOM == imp_Versatile.ZOOM_LEVEL_20:
                    w_MASK_ZOOM = (w_MASK_ZOOM | imp_Versatile.MASK_ZOOM_20)
                elif wZOOM == imp_Versatile.ZOOM_LEVEL_21:
                    w_MASK_ZOOM = (w_MASK_ZOOM | imp_Versatile.MASK_ZOOM_21)

            # ===== 取得データ作成 =====
            jsonList = []

            if dCnt > 0:
                jsonList.append({imp_Versatile.MAPDATA_GROUP_ID : wGROUP_ID,
                                 imp_Versatile.MAPDATA_KEEP_ZOOM_LEVEL : w_MASK_ZOOM,
                                 imp_Versatile.MAPDATA_TILE_NUM_X : wTILE_NUM_X,
                                 imp_Versatile.MAPDATA_TILE_NUM_Y : wTILE_NUM_Y,
                                 imp_Versatile.MAPDATA_TILE_BASECODE_X : wTILE_BASECODE_X,
                                 imp_Versatile.MAPDATA_TILE_BASECODE_Y : wTILE_BASECODE_Y
                             })
    
                # ===== json変換 jsonは文字、数値のみ（日付型は変換が必要）=====
                jsonString = json.dumps(jsonList, sort_keys=False, indent=4)
            else:
                dCnt = 0

            # ===== 戻り値セット =====
            ret = True

        except Exception as e:
            # ========== 例外処理 ==========
            print "[mapdb_error]", "Exception", sys._getframe().f_code.co_name, e.args

            # ===== 戻り値セット =====
            ret = False
            jsonString = ""
            dCnt = 0

        finally:
            # ========== 終了処理 ==========
            # ===== DB関連クローズ =====
            cursor.close()

            # ===== 戻り値 =====
            return (ret, jsonString, dCnt)


# ============================================================================
#  処　理：地図画像付加データ取得
#  引　数：[ulZoomLevel]:ズームレベル,[ulTileX]:タイルX座標, [ulTileY]:タイルY座標
#  戻り値：[ret]成功(True)/失敗(False),[jsonstring]:作成データ,[dCnt]:取得件数
# ============================================================================
    def getAddData(self, ulGroupId, ulZoomLevel, ulTileX, ulTileY):
        ret = False
        jsonString = ""
        dCnt = 0

        try:

            # ===== カーソール設定　=====
            cursor = self._dbconnect.cursor()

            # ===== 地図画像付加データ取得 sql文生成 =====
            sql = ""
            sql = sql + " select * from synthesis_plan_detail "
            sql = sql + " where group_id = %s and zoom_level = %s "
            sql = sql + "   and x_coordinate = %s and y_coordinate = %s "
            # ===== 地図画像付加データ取得 sql実行 =====
            cursor.execute(sql % (ulGroupId, ulZoomLevel, ulTileX, ulTileY))

            # ===== データ件数 =====
            dCnt = cursor.rowcount

            # ===== 結果をセット配列化 =====
            result = cursor.fetchall()

            # ===== 取得データ =====
            jsonList = []

            if dCnt > 0:
                for row in result:
                    jsonList.append({imp_Versatile.MAPDATA_GROUP_ID: row[1],
                                     imp_Versatile.MAPDATA_TILE_NAME: row[2],
                                     imp_Versatile.MAPDATA_FOLDER_PATH: row[3],
                                     imp_Versatile.MAPDATA_ZOOM_LEVEL: row[4],
                                     imp_Versatile.MAPDATA_TILECODE_X: row[5],
                                     imp_Versatile.MAPDATA_TILECODE_Y: row[6],
                                     imp_Versatile.MAPDATA_START_LATITUDE: row[7],
                                     imp_Versatile.MAPDATA_START_LONGITUDE: row[8],
                                     imp_Versatile.MAPDATA_END_LATITUDE: row[9],
                                     imp_Versatile.MAPDATA_END_LONGITUDE: row[10],
                                     imp_Versatile.MAPDATA_CREATE_DATE: row[11],
                                     imp_Versatile.MAPDATA_PLAN_NAME: row[12]
                                     })

                # ===== json変換 jsonは文字、数値のみ（日付型は変換が必要）=====
                jsonString = json.dumps(jsonList, sort_keys=False, indent=4)

            # ===== 戻り値セット =====
            ret = True

        except Exception as e:
            # ========== 例外処理 ==========
            print "[mapdb_error]", "Exception", sys._getframe().f_code.co_name, e.args

            # ===== 戻り値セット =====
            sts = False
            jsonString = ""
            dCnt = 0

        finally:
            # ========== 終了処理 ==========
            # ===== DB関連クローズ =====
            cursor.close()

            # ===== 戻り値 =====
            return (ret, jsonString, dCnt)


# ============================================================================
#  処　理：合成計画リスト作成
#  引　数：なし
#  戻り値：[ret]:成功(True)/失敗(False),[jsonstring]:作成データ,[dCnt]:作成件数
# ============================================================================
    def makeSynthesisPlanList(self):
        ret = False
        jsonString = ""
        dCnt = 0

        try:

            # ===== カーソール設定　=====
            cursor = self._dbconnect.cursor()

            # ====== 合成計画リスト並び順 =====
            if (self._confAlignmentSeq[0] == ""):
                s_AlignmentSeq = "desc"
            else:
                s_AlignmentSeq = self._confAlignmentSeq[0]

            # ===== sql文生成 =====
            sql = ""
            sql = sql + " select * from synthesis_plan "
            sql = sql + " order by create_date %s ,synthesis_plan_name asc limit %s"

            # ===== sql実行 =====
            cursor.execute(sql % (s_AlignmentSeq, imp_Versatile.PLAN_LIST_NUM_MAX))
            # ===== データ件数 =====
            dCnt = cursor.rowcount

            # ===== 結果をセット配列化 =====
            result = cursor.fetchall()

            # ===== 取得データ json =====
            jsonList = []
            if dCnt > 0:
                for row in result:
                    jsonList.append({imp_Versatile.MAPDATA_GROUP_ID: row[0],
                                     imp_Versatile.MAPDATA_CREATE_DATE: row[1],
                                     imp_Versatile.MAPDATA_PLAN_NAME: row[2]}
                                    )

                # ===== json変換 jsonは文字、数値のみ（日付型は変換が必要）=====
                jsonString = json.dumps(jsonList, sort_keys=False, indent=4)

            # ===== 戻り値セット =====
            ret = True

        except Exception as e:
            # ========== 例外処理 ==========
            print "[mapdb_error]", "Exception", sys._getframe().f_code.co_name, e

            # ===== 戻り値セット =====
            ret = False
            jsonString = ""
            dCnt = 0

        finally:
            # ========== 終了処理 ==========
            # ===== DB関連クローズ =====
            cursor.close()

            # ===== 戻り値 =====
            return (ret, jsonString, dCnt)


# ============================================================================
#  処　理：地図データ削除　ファイル、テーブル　
#  引　数：[ulGroupId]:グループＩＤ
#  戻り値：[ret]:成功(True)/失敗(False),[dCnt]:削除データ件数
# ============================================================================
    def delSynthesisPlanList(self, ulGroupId):
        ret = False
        dCnt = 0

        try:

            # ===== カーソール設定　=====
            cursor = self._dbconnect.cursor()
            cursor1 = self._dbconnect.cursor()
            cursor2 = self._dbconnect.cursor()

            # ===== グループIDで抽出 sql文生成（削除件数） =====
            sql = ""
            sql = sql + " select * from synthesis_plan_detail "
            sql = sql + " where group_id = %s "

            # ===== グループIDで抽出 sql実行 =====
            cursor.execute(sql % (ulGroupId))

            # ===== データ件数 =====
            dCnt = cursor.rowcount

            # ========== 削除処理 ==========
            if dCnt > 0:
                 # ===== グループIDで抽出 sql文生成(folder_pathでグループ化) =====
                sql = ""
                sql = sql + " select * from synthesis_plan_detail "
                sql = sql + " where group_id = %s "
                sql = sql + " group by folder_path "

                # ===== グループIDで抽出 sql実行 =====
                cursor.execute(sql % (ulGroupId))

                # ===== 結果をセット配列化 =====
                result = cursor.fetchall()

                # ===== 基本フォルダーセット =====
                basePath = imp_Versatile.MAP_BASE_FOLDER_PATH + imp_Versatile.TILE_FOLDER

                # ===== フォルダパス情報セット =====
                delList = []
                for row in result:
                    delList.append(basePath + row[3])

                # ===== 地図フォルダ削除 =====
                for delPath in delList:
                    delPath.replace('\t', '\\t')
                    # ===== フォルダ確認 =====
                    if os.path.exists(delPath):
                        # ===== ディレクトリツリー全体を削除する。 =====
                        shutil.rmtree(delPath)
                    else:
                        print u"[mapdb_warning]削除するフォルダがありません",delPath

                # ===== [合成計画リスト]テーブル削除sql文生成 =====
                sql = ""
                sql = sql + " delete from synthesis_plan "
                sql = sql + " where group_id = %s "

                # ===== [合成計画]テーブル削除 sql実行 =====
                cursor1.execute(sql % (ulGroupId))
                print "delSynthesisPlanList",ulGroupId
                # ===== [合成計画リスト詳細]テーブル削除　sql文生成 =====
                sql = ""
                sql = sql + " delete from synthesis_plan_detail "
                sql = sql + " where group_id = %s "

                # ===== ===== [合成計画リスト詳細]テーブル削除 sql実行 =====
                cursor2.execute(sql % (ulGroupId))

                # ===== コミット ======
                self._dbconnect.commit()

            # ===== 戻り値セット =====
            ret = True

        except Exception as e:
            # ========== 例外処理 ==========
            print "[mapdb_error]", "Exception", sys._getframe().f_code.co_name, e

            # ===== ロールバック =======
            self._dbconnect.rollback()

            # ===== 戻り値セット =====
            ret = False
            dCnt = 0

        finally:
            # ========== 終了処理 ==========
            # ===== DB関連クローズ =====
            cursor.close()
            cursor1.close()
            cursor2.close()

            # ===== 戻り値 =====
            return (ret, dCnt)


def MapDataDBControlInit(manager):
    profile = OpenRTM_aist.Properties(defaults_str=mapdatadbcontrol_spec)
    manager.registerFactory(profile,
                            MapDataDBControl,
                            OpenRTM_aist.Delete)


def MyModuleInit(manager):
    MapDataDBControlInit(manager)

    # Create a component
    comp = manager.createComponent("MapDataDBControl")


def main():
    mgr = OpenRTM_aist.Manager.init(sys.argv)
    mgr.setModuleInitProc(MyModuleInit)
    mgr.activateManager()
    mgr.runManager()

if __name__ == "__main__":
    main()
